@@ -9,6 +9,11 @@ module.exports = function (config) {
       "tests_browser/**/*.js",
       { pattern: `${outputDir}/*.wasm`, included: false, served: true },
     ],
+    client: {
+      mocha: {
+        timeout: 60000
+      }
+    },
     webpack: {
       mode: "development",
       module: {
