@@ -8,7 +8,7 @@ use derive_more::{From, Into};
 
 use crate::error_conversion::to_js;
 use ergo_lib::chain::ergo_state_context::Headers;
-use std::convert::TryInto;
+use std::convert::{TryFrom, TryInto};
 
 /// Block header
 #[wasm_bindgen]
@@ -100,10 +100,19 @@ impl From<BlockHeaders> for Vec<Header> {
     }
 }
 
-impl From<BlockHeaders> for Headers {
-    fn from(bs: BlockHeaders) -> Self {
+impl TryFrom<BlockHeaders> for Headers {
+    type Error = JsValue;
+    fn try_from(bs: BlockHeaders) -> Result<Self, Self::Error> {
         let headers: Vec<Header> = bs.0.into_iter().map(Header::from).collect();
-
-        headers.try_into().unwrap()
+        if headers.len() == 10 {
+            #[allow(clippy::unwrap_used)]
+            Ok(headers.try_into().unwrap())
+        } else {
+            Err(js_sys::Error::new(&format!(
+                "Incorrect number of block headers, expected 10 but got {}",
+                headers.len()
+            ))
+            .into())
+        }
     }
 }
