@@ -1,4 +1,5 @@
 //! Simple box selection algorithms
+use ergo_lib::ergotree_ir::chain;
 use ergo_lib::wallet;
 use ergo_lib::wallet::box_selector::BoxSelector;
 use wasm_bindgen::prelude::*;
@@ -8,6 +9,7 @@ use crate::ergo_box::BoxValue;
 use crate::ergo_box::ErgoBoxAssetsDataList;
 use crate::error_conversion::to_js;
 use crate::token::Tokens;
+use bounded_vec::BoundedVec;
 
 extern crate derive_more;
 use derive_more::{From, Into};
@@ -23,18 +25,18 @@ pub struct BoxSelection(
 impl BoxSelection {
     /// Create a selection to easily inject custom selection algorithms
     #[wasm_bindgen(constructor)]
-    pub fn new(boxes: &ErgoBoxes, change: &ErgoBoxAssetsDataList) -> Self {
-        BoxSelection(wallet::box_selector::BoxSelection::<
+    pub fn new(boxes: &ErgoBoxes, change: &ErgoBoxAssetsDataList) -> Result<BoxSelection, JsValue> {
+        Ok(BoxSelection(wallet::box_selector::BoxSelection::<
             ergo_lib::ergotree_ir::chain::ergo_box::ErgoBox,
         > {
-            boxes: boxes.clone().into(),
+            boxes: BoundedVec::from_vec(boxes.clone().into()).map_err(to_js)?,
             change_boxes: change.clone().into(),
-        })
+        }))
     }
 
     /// Selected boxes to spend as transaction inputs
     pub fn boxes(&self) -> ErgoBoxes {
-        self.0.boxes.clone().into()
+        self.0.boxes.as_vec().clone().into()
     }
 
     /// Selected boxes to use as change
@@ -66,13 +68,15 @@ impl SimpleBoxSelector {
         target_balance: &BoxValue,
         target_tokens: &Tokens,
     ) -> Result<BoxSelection, JsValue> {
-        let target_tokens: Vec<ergo_lib::ergotree_ir::chain::token::Token> =
-            target_tokens.clone().into();
+        let target_tokens: Option<chain::ergo_box::BoxTokens> = target_tokens.clone().into();
         self.0
             .select(
                 inputs.clone().into(),
                 target_balance.clone().into(),
-                target_tokens.as_slice(),
+                target_tokens
+                    .as_ref()
+                    .map(chain::ergo_box::BoxTokens::as_slice)
+                    .unwrap_or(&[]),
             )
             .map_err(to_js)
             .map(BoxSelection)
