@@ -1,5 +1,7 @@
 //! Ergo blockchain state (for ErgoTree evaluation)
 use ergo_lib::chain;
+use ergo_lib::chain::ergo_state_context::Headers;
+use std::convert::TryFrom;
 use wasm_bindgen::prelude::*;
 
 extern crate derive_more;
@@ -18,17 +20,7 @@ impl ErgoStateContext {
     /// Create new context from pre-header
     #[wasm_bindgen(constructor)]
     pub fn new(pre_header: PreHeader, headers: BlockHeaders) -> Result<ErgoStateContext, JsValue> {
-        match headers.len() {
-            10 => Ok(chain::ergo_state_context::ErgoStateContext::new(
-                pre_header.into(),
-                headers.into(),
-            )
-            .into()),
-            h => Err(js_sys::Error::new(&format!(
-                "Not enough block headers, expected 10 but got {}",
-                h
-            ))
-            .into()),
-        }
+        let headers = Headers::try_from(headers)?;
+        Ok(chain::ergo_state_context::ErgoStateContext::new(pre_header.into(), headers).into())
     }
 }
