@@ -15,9 +15,14 @@
 #![allow(clippy::len_without_is_empty)]
 #![allow(clippy::unused_unit)]
 #![deny(clippy::wildcard_enum_match_arm)]
+#![deny(clippy::unwrap_used)]
+#![deny(clippy::expect_used)]
+#![deny(clippy::todo)]
+#![deny(clippy::unimplemented)]
 
 pub mod address;
 pub mod ast;
+pub mod batchmerkleproof;
 pub mod block_header;
 pub mod box_coll;
 pub mod box_selector;
@@ -33,13 +38,16 @@ pub mod merkleproof;
 pub mod nipopow;
 
 pub mod prover_result;
-pub mod rest;
 pub mod secret_key;
 pub mod token;
 pub mod transaction;
 pub mod tx_builder;
 pub mod utils;
+pub mod verifier;
 pub mod wallet;
 
 mod error_conversion;
 pub(crate) mod json;
+
+#[cfg(feature = "rest")]
+pub mod rest;
